/*
 * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */


package com.sun.ts.tests.jpa.common.schema30;

import javax.persistence.*;
import java.util.Map;
import java.util.Set;

/*
 * Department
 */
@Entity
@Table(name = "DEPARTMENT")
public class Department implements java.io.Serializable {

    // Instance variables
    private int id;
    private String name;
    private Map<String, Employee> lastNameEmployees;

    public Department() {
    }

    public Department(int id, String name) {
        this.id = id;
        this.name = name;
    }


    // ===========================================================
    // getters and setters for the state fields

    @Id
    @Column(name = "ID")
    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    @Column(name = "NAME")
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    // ===========================================================
    // getters and setters for the association fields

    @OneToMany(mappedBy = "department")
    @MapKey(name = "lastName")
    public Map<String, Employee> getLastNameEmployees() {
        return lastNameEmployees;
    }

    public void setLastNameEmployees(Map<String, Employee> lastNameEmployees) {
        this.lastNameEmployees = lastNameEmployees;
    }

    @Override
    public String toString() {
        StringBuilder result = new StringBuilder();
        result.append(this.getClass().getSimpleName() + "[");
        result.append("id: " + getId());
        result.append(",  name: " + getName());
        if (getLastNameEmployees().size()>0){
            result.append(",  EmpLastName:[ ");
            Set<Map.Entry<String, Employee>> set = getLastNameEmployees().entrySet();

            for (Map.Entry<String, Employee> me : set) {

                result.append("["+me.getKey() + ", " + me.getValue().getId()+" , "+ me.getValue().getFirstName()+"]");
            }
            result.append("]");
        }
        result.append("]");
        return result.toString();
    }
}
